# FiftyOne Brain -- Experiment: Uniqueness

How can we demonstrate that fiftyone can be used to rank samples in an
otherwise unlabeled (or labeled) dataset by their "uniqueness"? This directory
houses experiments to answer this and related questions.

Problem: Unlabeled

## Copyright

Copyright 2017-2023, Voxel51, Inc.<br> voxel51.com
